#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/1/4 17:00
Desc: 天天基金-基金档案
https://fundf10.eastmoney.com/jjfl_015641.html
"""

from io import StringIO

import pandas as pd
import requests


def fund_fee_em(symbol: str = "015641", indicator: str = "认购费率") -> pd.DataFrame:
    """
    天天基金-基金档案-购买信息
    https://fundf10.eastmoney.com/jjfl_015641.html
    :param symbol: 基金代码
    :type symbol: str
    :param indicator: choice of {"交易状态", "申购与赎回金额", "交易确认日", "运作费用", "认购费率", "申购费率", "赎回费率"}
    :type indicator: str
    :return: 交易规则
    :rtype: pandas.DataFrame
    """
    url = f"https://fundf10.eastmoney.com/jjfl_{symbol}.html"
    r = requests.get(url)

    if indicator == "交易状态":
        temp_df = pd.read_html(StringIO(r.text))[1]
    elif indicator == "申购与赎回金额":
        temp_df_1 = pd.read_html(StringIO(r.text))[2]
        temp_df_2 = pd.read_html(StringIO(r.text))[3]
        temp_df = pd.concat(objs=[temp_df_1, temp_df_2], ignore_index=True)
    elif indicator == "交易确认日":
        temp_df = pd.read_html(StringIO(r.text))[4]
    elif indicator == "运作费用":
        temp_df = pd.read_html(StringIO(r.text))[5]
    elif indicator == "认购费率":
        temp_df = pd.read_html(StringIO(r.text))[6]
        temp_df["原费率"] = temp_df["原费率|天天基金优惠费率"].str.split(
            "|", expand=True
        )[0]
        temp_df["天天基金优惠费率"] = temp_df["原费率|天天基金优惠费率"].str.split(
            "|", expand=True
        )[1]
        del temp_df["原费率|天天基金优惠费率"]
        temp_df.loc[3, "天天基金优惠费率"] = temp_df.loc[3, "原费率"]
        temp_df["原费率"] = temp_df["原费率"].str.strip()
        temp_df["天天基金优惠费率"] = temp_df["天天基金优惠费率"].str.strip()
    elif indicator == "申购费率":
        temp_df = pd.read_html(StringIO(r.text))[7]
        temp_df["原费率"] = temp_df[
            "原费率|天天基金优惠费率 银行卡购买|活期宝购买"
        ].str.split("|", expand=True)[0]
        temp_df["天天基金优惠费率-银行卡购买"] = temp_df[
            "原费率|天天基金优惠费率 银行卡购买|活期宝购买"
        ].str.split("|", expand=True)[1]
        temp_df["天天基金优惠费率-活期宝购买"] = temp_df[
            "原费率|天天基金优惠费率 银行卡购买|活期宝购买"
        ].str.split("|", expand=True)[2]
        del temp_df["原费率|天天基金优惠费率 银行卡购买|活期宝购买"]
        temp_df.loc[3, "天天基金优惠费率-银行卡购买"] = temp_df.loc[3, "原费率"]
        temp_df.loc[3, "天天基金优惠费率-活期宝购买"] = temp_df.loc[3, "原费率"]
        temp_df["原费率"] = temp_df["原费率"].str.strip()
        temp_df["天天基金优惠费率-银行卡购买"] = temp_df[
            "天天基金优惠费率-银行卡购买"
        ].str.strip()
        temp_df["天天基金优惠费率-活期宝购买"] = temp_df[
            "天天基金优惠费率-活期宝购买"
        ].str.strip()
    elif indicator == "赎回费率":
        temp_df = pd.read_html(StringIO(r.text))[8]
    else:
        temp_df = pd.DataFrame([])
    return temp_df


if __name__ == "__main__":
    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="交易状态")
    print(fund_fee_em_df)

    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="申购与赎回金额")
    print(fund_fee_em_df)

    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="交易确认日")
    print(fund_fee_em_df)

    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="运作费用")
    print(fund_fee_em_df)

    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="认购费率")
    print(fund_fee_em_df)

    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="申购费率")
    print(fund_fee_em_df)

    fund_fee_em_df = fund_fee_em(symbol="015641", indicator="赎回费率")
    print(fund_fee_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/1/20 22:30
Desc: FF-data-library
https://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html
"""

from io import StringIO

import pandas as pd
import requests

from akshare.article.cons import ff_home_url


def article_ff_crr() -> pd.DataFrame:
    """
    FF多因子模型
    https://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html
    :return: FF多因子模型单一表格
    :rtype: pandas.DataFrame
    """
    res = requests.get(ff_home_url)
    # first table
    list_index = (
        pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[2, :]
        .index.tolist()
    )
    list_0 = [
        item
        for item in pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[0, :]
        .iloc[0]
        .split(" ")
        if item != ""
    ]
    list_1 = [
        item
        for item in pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[0, :]
        .iloc[1]
        .split(" ")
        if item != ""
    ]
    list_2 = [
        item
        for item in pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[0, :]
        .iloc[2]
        .split(" ")
        if item != ""
    ]
    list_0.insert(0, "-")
    list_1.insert(0, "-")
    list_2.insert(0, "-")
    temp_columns = (
        pd.read_html(StringIO(res.text), header=0)[4]
        .iloc[:, 0]
        .str.split("  ", expand=True)
        .T[0]
        .dropna()
        .tolist()
    )
    table_one = pd.DataFrame(
        [list_0, list_1, list_2], index=list_index, columns=temp_columns
    ).T

    # second table
    list_index = (
        pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[1, :]
        .index.tolist()
    )
    list_0 = [
        item
        for item in pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[1, :]
        .iloc[0]
        .split(" ")
        if item != ""
    ]
    list_1 = [
        item
        for item in pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[1, :]
        .iloc[1]
        .split(" ")
        if item != ""
    ]
    list_2 = [
        item
        for item in pd.read_html(StringIO(res.text), header=0, index_col=0)[4]
        .iloc[1, :]
        .iloc[2]
        .split(" ")
        if item != ""
    ]
    list_0.insert(0, "-")
    list_1.insert(0, "-")
    list_2.insert(0, "-")
    temp_columns = (
        pd.read_html(StringIO(res.text), header=0)[4]
        .iloc[:, 0]
        .str.split("  ", expand=True)
        .T[1]
        .dropna()
        .tolist()
    )
    table_two = pd.DataFrame(
        [list_0, list_1, list_2], index=list_index, columns=temp_columns
    ).T

    # third table
    df = pd.read_html(StringIO(res.text), header=0, index_col=0)[4].iloc[2, :]
    name_list = (
        pd.read_html(StringIO(res.text), header=0)[4]
        .iloc[:, 0]
        .str.split(r"  ", expand=True)
        .iloc[2, :]
        .tolist()
    )
    value_list_0 = df.iloc[0].split("  ")
    value_list_0.insert(0, "-")
    value_list_0.insert(1, "-")
    value_list_0.insert(8, "-")
    value_list_0.insert(15, "-")

    value_list_1 = df.iloc[1].split("  ")
    value_list_1.insert(0, "-")
    value_list_1.insert(1, "-")
    value_list_1.insert(8, "-")
    value_list_1.insert(15, "-")

    value_list_2 = df.iloc[2].split("  ")
    value_list_2.insert(0, "-")
    value_list_2.insert(1, "-")
    value_list_2.insert(8, "-")
    value_list_2.insert(15, "-")

    name_list.remove("Small Growth Big Value")
    name_list.insert(5, "Small Growth")
    name_list.insert(6, "Big Value")
    temp_list = [item for item in name_list if "Portfolios" not in item]
    temp_list.insert(0, "Fama/French Research Portfolios")
    temp_list.insert(1, "Size and Book-to-Market Portfolios")
    temp_list.insert(8, "Size and Operating Profitability Portfolios")
    temp_list.insert(15, "Size and Investment Portfolios")
    temp_df = pd.DataFrame([temp_list, value_list_0, value_list_1, value_list_2]).T
    temp_df.index = temp_df.iloc[:, 0]
    temp_df = temp_df.iloc[:, 1:]
    # concat
    all_df = pd.DataFrame()
    all_df = pd.concat([all_df, table_one])
    all_df = pd.concat([all_df, table_two])
    temp_df.columns = table_two.columns
    all_df = pd.concat([all_df, temp_df])
    all_df.reset_index(inplace=True)
    all_df.rename(columns={"index": "item"}, inplace=True)
    return all_df


if __name__ == "__main__":
    article_ff_crr_df = article_ff_crr()
    print(article_ff_crr_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/3/21 11:16
Desc: 行情宝
https://hqb.nxin.com/pigindex/index.shtml
"""

import pandas as pd
import requests


def index_hog_spot_price() -> pd.DataFrame:
    """
    行情宝-生猪市场价格指数
    https://hqb.nxin.com/pigindex/index.shtml
    :return: 生猪市场价格指数
    :rtype: pandas.DataFrame
    """
    url = "https://hqb.nxin.com/pigindex/getPigIndexChart.shtml"
    params = {"regionId": "0"}
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df.columns = [
        "日期",
        "指数",
        "4个月均线",
        "6个月均线",
        "12个月均线",
        "预售均价",
        "成交均价",
        "成交均重",
    ]
    temp_df["日期"] = (
        pd.to_datetime(temp_df["日期"], unit="ms") + pd.Timedelta(hours=8)
    ).dt.date
    temp_df["指数"] = pd.to_numeric(temp_df["指数"], errors="coerce")
    temp_df["4个月均线"] = pd.to_numeric(temp_df["4个月均线"], errors="coerce")
    temp_df["6个月均线"] = pd.to_numeric(temp_df["6个月均线"], errors="coerce")
    temp_df["12个月均线"] = pd.to_numeric(temp_df["12个月均线"], errors="coerce")
    temp_df["预售均价"] = pd.to_numeric(temp_df["预售均价"], errors="coerce")
    temp_df["成交均价"] = pd.to_numeric(temp_df["成交均价"], errors="coerce")
    temp_df["成交均重"] = pd.to_numeric(temp_df["成交均重"], errors="coerce")
    return temp_df


if __name__ == "__main__":
    index_hog_spot_price_df = index_hog_spot_price()
    print(index_hog_spot_price_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/6 20:30
Desc: 同花顺-数据中心-营业部排名
https://data.10jqka.com.cn/market/longhu/
"""

from io import StringIO

import pandas as pd
import requests
from bs4 import BeautifulSoup

from akshare.utils.tqdm import get_tqdm
from akshare.utils.cons import headers


def stock_lh_yyb_most() -> pd.DataFrame:
    """
    同花顺-数据中心-营业部排名-上榜次数最多
    https://data.10jqka.com.cn/market/longhu/
    :return: 上榜次数最多
    :rtype: pandas.DataFrame
    """
    url = "https://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/sbcs/field/sbcs/sort/desc/page/1/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    page_str = soup.find(name="span", attrs={"class": "page_info"}).text
    total_page = int(page_str.split("/")[1]) + 1
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page), leave=False):
        url = f"https://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/sbcs/field/sbcs/sort/desc/page/{page}/"
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def stock_lh_yyb_capital() -> pd.DataFrame:
    """
    同花顺-数据中心-营业部排名-资金实力最强
    https://data.10jqka.com.cn/market/longhu/
    :return: 资金实力最强
    :rtype: pandas.DataFrame
    """
    url = "https://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/zjsl/field/zgczje/sort/desc/page/1/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    page_str = soup.find(name="span", attrs={"class": "page_info"}).text
    total_page = int(page_str.split("/")[1]) + 1
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page), leave=False):
        url = f"https://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/zjsl/field/zgczje/sort/desc/page/{page}/"
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def stock_lh_yyb_control() -> pd.DataFrame:
    """
    同花顺-数据中心-营业部排名-抱团操作实力
    https://data.10jqka.com.cn/market/longhu/
    :return: 抱团操作实力
    :rtype: pandas.DataFrame
    """
    url = "https://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/btcz/field/xsjs/sort/desc/page/1/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    page_str = soup.find(name="span", attrs={"class": "page_info"}).text
    total_page = int(page_str.split("/")[1]) + 1
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page), leave=False):
        url = f"https://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/btcz/field/xsjs/sort/desc/page/{page}/"
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


if __name__ == "__main__":
    stock_lh_yyb_most_df = stock_lh_yyb_most()
    print(stock_lh_yyb_most_df)

    stock_lh_yyb_capital_df = stock_lh_yyb_capital()
    print(stock_lh_yyb_capital_df)

    stock_lh_yyb_control_df = stock_lh_yyb_control()
    print(stock_lh_yyb_control_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/7 17:00
Desc: 新浪财经-行情中心-环球市场
https://finance.sina.com.cn/stock/globalindex/quotes/UKX
"""

import pandas as pd
import requests

from akshare.index.cons import index_global_sina_symbol_map


def index_global_name_table() -> pd.DataFrame:
    """
    新浪财经-行情中心-环球市场-名称代码映射表
    https://finance.sina.com.cn/stock/globalindex/quotes/UKX
    :return: 名称代码映射表
    :rtype: pandas.DataFrame
    """
    temp_df = pd.DataFrame.from_dict(
        index_global_sina_symbol_map, orient="index", columns=["代码"]
    )
    temp_df.index.name = "指数名称"
    temp_df.reset_index(inplace=True)
    return temp_df


def index_global_hist_sina(symbol: str = "OMX") -> pd.DataFrame:
    """
    新浪财经-行情中心-环球市场-历史行情
    https://finance.sina.com.cn/stock/globalindex/quotes/UKX
    :param symbol: 指数名称；可以通过 ak.index_global_name_table() 获取
    :type symbol: str
    :return: 环球市场历史行情
    :rtype: pandas.DataFrame
    """
    url = "https://gi.finance.sina.com.cn/hq/daily"
    params = {
        "symbol": index_global_sina_symbol_map[symbol],
        "num": "10000",
    }
    r = requests.get(url=url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    temp_df.rename(
        columns={
            "d": "date",
            "o": "open",
            "h": "high",
            "l": "low",
            "c": "close",
            "v": "volume",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "date",
            "open",
            "high",
            "low",
            "close",
            "volume",
        ]
    ]
    temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
    temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
    temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
    temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
    temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
    temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
    return temp_df


if __name__ == "__main__":
    index_global_name_table_df = index_global_name_table()
    print(index_global_name_table_df)

    index_global_hist_sina_df = index_global_hist_sina(symbol="瑞士股票指数")
    print(index_global_hist_sina_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2024/5/16 20:00
Desc: 99 期货-数据-期现-现货走势
https://www.99qh.com/data/spotTrend
"""

import json

import pandas as pd
import requests
from bs4 import BeautifulSoup


def __get_item_of_spot_price_qh() -> pd.DataFrame:
    """
    99 期货-数据-期现-品种和 ID 对应表
    https://www.99qh.com/data/spotTrend
    :return: 品种和 ID 对应表
    :rtype: str
    """
    url = "https://www.99qh.com/data/spotTrend"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, features="lxml")
    data_text = soup.find(name="script", attrs={"id": "__NEXT_DATA__"}).text
    data_json = json.loads(data_text)
    big_list = []
    for item in data_json["props"]["pageProps"]["data"]["varietyListData"]:
        big_list.extend(item["productList"])
    temp_df = pd.DataFrame(big_list)
    temp_df = temp_df[["qhExchangeName", "name", "productId"]]
    return temp_df


def __get_token_of_spot_price_qh() -> str:
    """
    99 期货-数据-期现-token
    https://www.99qh.com/data/spotTrend
    :return: token
    :rtype: str
    """
    url = "https://centerapi.fx168api.com/app/common/v.js"
    headers = {
        "Origin": "https://www.99qh.com",
        "Referer": "https://www.99qh.com",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/124.0.0.0 Safari/537.36",
    }
    r = requests.get(url, headers=headers)
    token = r.headers["_pcc"]
    return token


def spot_price_table_qh() -> pd.DataFrame:
    """
    99 期货-数据-期现-交易所与品种对照表
    https://www.99qh.com/data/spotTrend
    :return: 交易所与品种对照表
    :rtype: pandas.DataFrame
    """
    temp_df = __get_item_of_spot_price_qh()
    temp_df.rename(
        columns={
            "qhExchangeName": "交易所名称",
            "name": "品种名称",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "交易所名称",
            "品种名称",
        ]
    ]
    return temp_df


def spot_price_qh(symbol: str = "螺纹钢") -> pd.DataFrame:
    """
    99 期货-数据-期现-现货走势
    https://www.99qh.com/data/spotTrend
    :param symbol: 品种名称
    :type symbol: str
    :return: 现货走势
    :rtype: pandas.DataFrame
    """
    inner_df = __get_item_of_spot_price_qh()
    symbol_map = dict(zip(inner_df["name"], inner_df["productId"]))
    url = "https://centerapi.fx168api.com/app/qh/api/spot/trend"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/124.0.0.0 Safari/537.36",
        "_pcc": __get_token_of_spot_price_qh(),
        "Origin": "https://www.99qh.com",
        "Referer": "https://www.99qh.com",
    }
    params = {
        "productId": symbol_map[symbol],
        "pageNo": "1",
        "pageSize": "50000",
        "startDate": "",
        "endDate": "2050-01-01",
        "appCategory": "web",
    }
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["list"])
    temp_df.rename(
        columns={"date": "日期", "fp": "期货收盘价", "sp": "现货价格"}, inplace=True
    )
    temp_df.sort_values(by=["日期"], inplace=True, ignore_index=True)
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df["期货收盘价"] = pd.to_numeric(temp_df["期货收盘价"], errors="coerce")
    temp_df["现货价格"] = pd.to_numeric(temp_df["现货价格"], errors="coerce")
    return temp_df


if __name__ == "__main__":
    spot_price_qh_df = spot_price_qh(symbol="螺纹钢")
    print(spot_price_qh_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/11/16 20:40
Desc: 艺恩-艺人
艺人商业价值
艺人流量价值
https://www.endata.com.cn/Marketing/Artist/business.html
"""

import datetime
import json
import os

import pandas as pd  # type: ignore
import requests
import py_mini_racer  # type: ignore


def _get_js_path(name: str = "", module_file: str = "") -> str:
    """
    get JS file path
    :param name: file name
    :type name: str
    :param module_file: filename
    :type module_file: str
    :return: 路径
    :rtype: str
    """
    module_folder = os.path.abspath(os.path.dirname(os.path.dirname(module_file)))
    module_json_path = os.path.join(module_folder, "movie", name)
    return module_json_path


def _get_file_content(file_name: str = "jm.js"):
    """
    read the file content
    :param file_name: filename
    :type file_name: str
    :return: file content
    :rtype: str
    """
    setting_file_name = file_name
    setting_file_path = _get_js_path(setting_file_name, __file__)
    with open(setting_file_path) as f:
        file_data = f.read()
    return file_data


def decrypt(origin_data: str = "") -> str:
    """
    解密艺恩的加密数据
    :param origin_data: 解密前的字符串
    :type origin_data: str
    :return: 解密后的字符串
    :rtype: str
    """
    file_data = _get_file_content(file_name="jm.js")
    ctx = py_mini_racer.MiniRacer()
    ctx.eval(file_data)
    data = ctx.call("webInstace.shell", origin_data)
    return data


def business_value_artist() -> pd.DataFrame:
    """
    艺恩-艺人-艺人商业价值
    https://www.endata.com.cn/Marketing/Artist/business.html
    :return: 艺人商业价值
    :rtype: pandas.DataFrame
    """
    url = "https://www.endata.com.cn/API/GetData.ashx"
    payload = {
        "Order": "BusinessValueIndex_L1",
        "OrderType": "DESC",
        "PageIndex": "1",
        "PageSize": "100",
        "MethodName": "Data_GetList_Star",
    }
    r = requests.post(url, data=payload)
    r.encoding = "utf8"
    data_json = json.loads(decrypt(r.text))
    temp_df = pd.DataFrame(data_json["Data"]["Table"])
    temp_df.columns = [
        "排名",
        "-",
        "艺人",
        "商业价值",
        "-",
        "专业热度",
        "关注热度",
        "预测热度",
        "美誉度",
        "-",
    ]
    temp_df = temp_df[
        ["排名", "艺人", "商业价值", "专业热度", "关注热度", "预测热度", "美誉度"]
    ]
    temp_df["统计日期"] = datetime.datetime.now().date().isoformat()
    return temp_df


def online_value_artist() -> pd.DataFrame:
    """
    艺恩-艺人-艺人流量价值
    https://www.endata.com.cn/Marketing/Artist/business.html
    :return: 艺人流量价值
    :rtype: pandas.DataFrame
    """
    url = "https://www.endata.com.cn/API/GetData.ashx"
    payload = {
        "Order": "FlowValueIndex_L1",
        "OrderType": "DESC",
        "PageIndex": 1,
        "PageSize": 100,
        "MethodName": "Data_GetList_Star",
    }
    r = requests.post(url, data=payload)
    r.encoding = "utf8"
    data_json = json.loads(decrypt(r.text))
    temp_df = pd.DataFrame(data_json["Data"]["Table"])
    temp_df.columns = [
        "排名",
        "-",
        "艺人",
        "-",
        "流量价值",
        "专业热度",
        "关注热度",
        "预测热度",
        "-",
        "带货力",
    ]
    temp_df = temp_df[
        ["排名", "艺人", "流量价值", "专业热度", "关注热度", "预测热度", "带货力"]
    ]
    temp_df["统计日期"] = datetime.datetime.now().date().isoformat()
    return temp_df


if __name__ == "__main__":
    business_value_artist_df = business_value_artist()
    print(business_value_artist_df)

    online_value_artist_df = online_value_artist()
    print(online_value_artist_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/15 18:20
Desc: 华尔街见闻-日历-宏观
https://wallstreetcn.com/calendar
"""

from datetime import datetime, timedelta

import numpy as np
import pandas as pd
import requests


def __convert_date_format(date: str) -> str:
    """
    将日期字符串从格式'%Y%m%d'转换为格式'%Y-%m-%d %H:%M:%S'。

    :param date: 日期字符串,格式为'%Y%m%d'
    :return: 转换后的日期字符串,格式为'%Y-%m-%d %H:%M:%S'
    """
    datetime_obj = datetime.strptime(date, "%Y%m%d")
    return datetime_obj.strftime("%Y-%m-%d %H:%M:%S")


def __format_date(date: str) -> int:
    """
    将日期字符串转换为Unix时间戳。

    :param date: 日期字符串,格式为'%Y-%m-%d %H:%M:%S'
    :return: Unix时间戳
    """
    datetime_obj = datetime.strptime(date, "%Y-%m-%d %H:%M:%S")
    return int(datetime_obj.timestamp())


def macro_info_ws(date: str = "20240514") -> pd.DataFrame:
    """
    华尔街见闻-日历-宏观
    https://wallstreetcn.com/calendar
    :param date: 日期
    :type date: str
    :return: 日历-宏观
    :rtype: pandas.DataFrame
    """
    date = __convert_date_format(date)
    url = "https://api-one-wscn.awtmt.com/apiv1/finance/macrodatas"
    datetime_obj = datetime.strptime(date, "%Y-%m-%d %H:%M:%S")
    one_day = timedelta(days=1)
    new_datetime = datetime_obj + one_day
    date_str = new_datetime.strftime("%Y-%m-%d %H:%M:%S")
    params = {"start": __format_date(date), "end": __format_date(date_str)}
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["items"])
    temp_df["public_date"] = pd.to_datetime(
        temp_df["public_date"], errors="coerce", unit="s", utc=True
    ).dt.tz_convert("Asia/Shanghai")
    temp_df["public_date"] = temp_df["public_date"].dt.strftime("%Y-%m-%d %H:%M:%S")
    temp_df = temp_df.rename(
        columns={
            "public_date": "时间",
            "country": "地区",
            "title": "事件",
            "importance": "重要性",
            "actual": "今值",
            "forecast": "预期",
            "previous": "前值",
            "revised": "修正",
            "uri": "链接",
        }
    )
    temp_df = temp_df[
        [
            "时间",
            "地区",
            "事件",
            "重要性",
            "今值",
            "预期",
            "前值",
            "修正",
            "链接",
        ]
    ]
    temp_df["今值"] = pd.to_numeric(temp_df["今值"], errors="coerce")
    temp_df["预期"] = pd.to_numeric(temp_df["预期"], errors="coerce")
    temp_df["前值"] = pd.to_numeric(temp_df["前值"], errors="coerce")
    temp_df["修正"] = pd.to_numeric(temp_df["修正"], errors="coerce")
    temp_df["前值"] = np.where(
        temp_df["修正"].notnull(), temp_df["修正"], temp_df["前值"]
    )
    del temp_df["修正"]
    return temp_df


if __name__ == "__main__":
    macro_info_ws_df = macro_info_ws(date="20240514")
    print(macro_info_ws_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/9 23:00
Desc: 东方财富网-行情中心-沪深港通
https://quote.eastmoney.com/center/gridlist.html#ah_comparison
"""

import math

import pandas as pd
import requests

from akshare.utils.tqdm import get_tqdm
from akshare.utils.func import fetch_paginated_data


def stock_zh_ah_spot_em() -> pd.DataFrame:
    """
    东方财富网-行情中心-沪深港通-AH股比价-实时行情
    https://quote.eastmoney.com/center/gridlist.html#ah_comparison
    :return: 东方财富网-行情中心-沪深港通-AH股比价-实时行情
    :rtype: pandas.DataFrame
    """
    url = "https://push2.eastmoney.com/api/qt/clist/get"
    params = {
        "np": "1",
        "fltt": "1",
        "invt": "2",
        "fs": "b:DLMK0101",
        "fields": "f193,f191,f192,f12,f13,f14,f1,f2,f4,f3,f152,f186,f190,f187,f189,f188",
        "fid": "f3",
        "pn": "1",
        "pz": "100",
        "po": "1",
        "dect": "1",
        "wbp2u": "|0|0|0|web",
    }
    temp_df = fetch_paginated_data(url, params)
    temp_df.reset_index(inplace=True)
    temp_df["index"] = temp_df["index"].astype(int) + 1
    temp_df.rename(
        columns={
            "index": "序号",
            "f193": "名称",
            "f12": "H股代码",
            "f2": "最新价-HKD",
            "f3": "H股-涨跌幅",
            "f191": "A股代码",
            "f186": "最新价-RMB",
            "f187": "A股-涨跌幅",
            "f189": "比价",
            "f188": "溢价",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "序号",
            "名称",
            "H股代码",
            "最新价-HKD",
            "H股-涨跌幅",
            "A股代码",
            "最新价-RMB",
            "A股-涨跌幅",
            "比价",
            "溢价",
        ]
    ]
    temp_df["最新价-HKD"] = pd.to_numeric(temp_df["最新价-HKD"], errors="coerce") / 1000
    temp_df["H股-涨跌幅"] = pd.to_numeric(temp_df["H股-涨跌幅"], errors="coerce") / 100
    temp_df["最新价-RMB"] = pd.to_numeric(temp_df["最新价-RMB"], errors="coerce") / 100
    temp_df["A股-涨跌幅"] = pd.to_numeric(temp_df["A股-涨跌幅"], errors="coerce") / 100
    temp_df["比价"] = pd.to_numeric(temp_df["比价"], errors="coerce") / 100
    temp_df["溢价"] = pd.to_numeric(temp_df["溢价"], errors="coerce") / 100
    return temp_df


def stock_hsgt_sh_hk_spot_em() -> pd.DataFrame:
    """
    东方财富网-行情中心-沪深港通-港股通(沪>港)-股票
    https://quote.eastmoney.com/center/gridlist.html#hk_sh_stocks
    :return: 东方财富网-行情中心-沪深港通-港股通(沪>港)-股票
    :rtype: pandas.DataFrame
    """
    url = "https://push2.eastmoney.com/api/qt/clist/get"
    params = {
        "np": "1",
        "fltt": "1",
        "invt": "2",
        "fs": "b:DLMK0144",
        "fields": "f12,f13,f14,f19,f1,f2,f4,f3,f152,f17,f18,f15,f16,f5,f6",
        "fid": "f12",
        "pn": "1",
        "pz": "100",
        "po": "1",
        "dect": "1",
        "wbp2u": "|0|0|0|web",
    }
    temp_df = fetch_paginated_data(url, params)
    temp_df.rename(
        columns={
            "f12": "代码",
            "f14": "名称",
            "f2": "最新价",
            "f4": "涨跌额",
            "f3": "涨跌幅",
            "f17": "今开",
            "f15": "最高",
            "f16": "最低",
            "f18": "昨收",
            "f5": "成交量",
            "f6": "成交额",
        },
        inplace=True,
    )

    temp_df = temp_df[
        [
            "代码",
            "名称",
            "最新价",
            "涨跌额",
            "涨跌幅",
            "今开",
            "最高",
            "最低",
            "昨收",
            "成交量",
            "成交额",
        ]
    ]
    temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce") / 1000
    temp_df["涨跌额"] = pd.to_numeric(temp_df["涨跌额"], errors="coerce") / 1000
    temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce") / 100
    temp_df["今开"] = pd.to_numeric(temp_df["今开"], errors="coerce") / 1000
    temp_df["最高"] = pd.to_numeric(temp_df["最高"], errors="coerce") / 1000
    temp_df["最低"] = pd.to_numeric(temp_df["最低"], errors="coerce") / 1000
    temp_df["昨收"] = pd.to_numeric(temp_df["昨收"], errors="coerce") / 1000
    temp_df["成交量"] = pd.to_numeric(temp_df["成交量"], errors="coerce") / 100000000
    temp_df["成交额"] = pd.to_numeric(temp_df["成交额"], errors="coerce") / 100000000
    temp_df.sort_values(["代码"], ignore_index=True, inplace=True)
    temp_df.reset_index(inplace=True)
    temp_df["index"] = temp_df["index"].astype(int) + 1
    temp_df.rename(columns={"index": "序号"}, inplace=True)
    return temp_df


if __name__ == "__main__":
    stock_zh_ah_spot_em_df = stock_zh_ah_spot_em()
    print(stock_zh_ah_spot_em_df)

    stock_hsgt_sh_hk_spot_em_df = stock_hsgt_sh_hk_spot_em()
    print(stock_hsgt_sh_hk_spot_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/4 17:00
Desc: 港股-基本面数据
https://emweb.securities.eastmoney.com/PC_HKF10/FinancialAnalysis/index?type=web&code=00700
"""

import pandas as pd
import requests


def stock_financial_hk_report_em(
    stock: str = "00700", symbol: str = "资产负债表", indicator: str = "年度"
) -> pd.DataFrame:
    """
    东方财富-港股-财务报表-三大报表
    https://emweb.securities.eastmoney.com/PC_HKF10/FinancialAnalysis/index?type=web&code=00700
    :param stock: 股票代码
    :type stock: str
    :param symbol: choice of {"资产负债表", "利润表", "现金流量表"}
    :type symbol: str
    :param indicator: choice of {"年度", "报告期"}
    :type indicator: str
    :return: 东方财富-港股-财务报表-三大报表
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter.eastmoney.com/securities/api/data/v1/get"
    params = {
        "reportName": "RPT_CUSTOM_HKSK_APPFN_CASHFLOW_SUMMARY",
        "columns": "SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,START_DATE,REPORT_DATE,FISCAL_YEAR,"
        "CURRENCY,ACCOUNT_STANDARD,REPORT_TYPE",
        "quoteColumns": "",
        "filter": f'(SECUCODE="{stock}.HK")',
        "source": "F10",
        "client": "PC",
        "v": "02092616586970355",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"][0]["REPORT_LIST"])
    if indicator == "年度":
        temp_df = temp_df[temp_df["REPORT_TYPE"] == "年报"]
    else:
        temp_df = temp_df
    year_list = [item.split(" ")[0] for item in temp_df["REPORT_DATE"]]
    if symbol == "资产负债表":
        params = {
            "reportName": "RPT_HKF10_FN_BALANCE_PC",
            "columns": "SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,ORG_CODE,REPORT_DATE,DATE_TYPE_CODE,"
            "FISCAL_YEAR,STD_ITEM_CODE,STD_ITEM_NAME,AMOUNT,STD_REPORT_DATE",
            "quoteColumns": "",
            "filter": f"""(SECUCODE="{stock}.HK")(REPORT_DATE in ({"'" + "','".join(year_list) + "'"}))""",
            "pageNumber": "1",
            "pageSize": "",
            "sortTypes": "-1,1",
            "sortColumns": "REPORT_DATE,STD_ITEM_CODE",
            "source": "F10",
            "client": "PC",
            "v": "01975982096513973",
        }
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        return temp_df
    elif symbol == "利润表":
        params = {
            "reportName": "RPT_HKF10_FN_INCOME_PC",
            "columns": "SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,ORG_CODE,REPORT_DATE,DATE_TYPE_CODE,"
            "FISCAL_YEAR,START_DATE,STD_ITEM_CODE,STD_ITEM_NAME,AMOUNT",
            "quoteColumns": "",
            "filter": f"""(SECUCODE="{stock}.HK")(REPORT_DATE in ({"'" + "','".join(year_list) + "'"}))""",
            "pageNumber": "1",
            "pageSize": "",
            "sortTypes": "-1,1",
            "sortColumns": "REPORT_DATE,STD_ITEM_CODE",
            "source": "F10",
            "client": "PC",
            "v": "01975982096513973",
        }
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        return temp_df
    elif symbol == "现金流量表":
        params = {
            "reportName": "RPT_HKF10_FN_CASHFLOW_PC",
            "columns": "SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,ORG_CODE,REPORT_DATE,DATE_TYPE_CODE,"
            "FISCAL_YEAR,START_DATE,STD_ITEM_CODE,STD_ITEM_NAME,AMOUNT",
            "quoteColumns": "",
            "filter": f"""(SECUCODE="{stock}.HK")(REPORT_DATE in ({"'" + "','".join(year_list) + "'"}))""",
            "pageNumber": "1",
            "pageSize": "",
            "sortTypes": "-1,1",
            "sortColumns": "REPORT_DATE,STD_ITEM_CODE",
            "source": "F10",
            "client": "PC",
            "v": "01975982096513973",
        }
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        return temp_df
    else:
        return pd.DataFrame()


def stock_financial_hk_analysis_indicator_em(
    symbol: str = "00853", indicator: str = "年度"
) -> pd.DataFrame:
    """
    东方财富-港股-财务分析-主要指标
    https://emweb.securities.eastmoney.com/PC_HKF10/NewFinancialAnalysis/index?type=web&code=00700
    :param symbol: 股票代码
    :type symbol: str
    :param indicator: choice of {"年度", "报告期"}
    :type indicator: str
    :return: 新浪财经-港股-财务分析-主要指标
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter.eastmoney.com/securities/api/data/v1/get"
    params = {
        "reportName": "RPT_HKF10_FN_MAININDICATOR",
        "columns": "HKF10_FN_MAININDICATOR",
        "quoteColumns": "",
        "pageNumber": "1",
        "pageSize": "9",
        "sortTypes": "-1",
        "sortColumns": "STD_REPORT_DATE",
        "source": "F10",
        "client": "PC",
        "v": "01975982096513973",
    }
    if indicator == "年度":
        params.update({"filter": f"""(SECUCODE="{symbol}.HK")(DATE_TYPE_CODE="001")"""})
    else:
        params.update({"filter": f"""(SECUCODE="{symbol}.HK")"""})
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    return temp_df


if __name__ == "__main__":
    stock_financial_hk_analysis_indicator_em_df = (
        stock_financial_hk_analysis_indicator_em(symbol="00700", indicator="年度")
    )
    print(stock_financial_hk_analysis_indicator_em_df)

    stock_financial_hk_analysis_indicator_em_df = (
        stock_financial_hk_analysis_indicator_em(symbol="00700", indicator="报告期")
    )
    print(stock_financial_hk_analysis_indicator_em_df)

    stock_financial_hk_report_em_df = stock_financial_hk_report_em(
        stock="01742", symbol="资产负债表", indicator="年度"
    )
    print(stock_financial_hk_report_em_df)

    stock_financial_hk_report_em_df = stock_financial_hk_report_em(
        stock="01742", symbol="资产负债表", indicator="报告期"
    )
    print(stock_financial_hk_report_em_df)

    stock_financial_hk_report_em_df = stock_financial_hk_report_em(
        stock="00700", symbol="利润表", indicator="年度"
    )
    print(stock_financial_hk_report_em_df)

    stock_financial_hk_report_em_df = stock_financial_hk_report_em(
        stock="00700", symbol="利润表", indicator="报告期"
    )
    print(stock_financial_hk_report_em_df)

    stock_financial_hk_report_em_df = stock_financial_hk_report_em(
        stock="00700", symbol="现金流量表", indicator="年度"
    )
    print(stock_financial_hk_report_em_df)

    stock_financial_hk_report_em_df = stock_financial_hk_report_em(
        stock="00700", symbol="现金流量表", indicator="报告期"
    )
    print(stock_financial_hk_report_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/1/26 15:10
Desc: 福布斯中国-榜单
https://www.forbeschina.com/lists
"""

import pandas as pd
import requests
from bs4 import BeautifulSoup


def forbes_rank(symbol: str = "2021福布斯中国创投人100") -> pd.DataFrame:
    """
    福布斯中国-榜单
    https://www.forbeschina.com/lists
    https://www.forbeschina.com/lists/1750
    :param symbol: choice of {"2020福布斯美国富豪榜", "2020福布斯新加坡富豪榜", "2020福布斯中国名人榜", *}
    :type symbol: str
    :return: 具体指标的榜单
    :rtype: pandas.DataFrame
    """
    url = "https://www.forbeschina.com/lists"
    r = requests.get(url, verify=False)
    soup = BeautifulSoup(r.text, "lxml")
    need_list = [
        item.find_all("a") for item in soup.find_all("div", attrs={"class": "col-sm-4"})
    ]
    all_list = []
    for item in need_list:
        all_list.extend(item)
    name_url_dict = dict(
        zip(
            [item.text.strip() for item in all_list],
            ["https://www.forbeschina.com" + item["href"] for item in all_list],
        )
    )
    r = requests.get(name_url_dict[symbol], verify=False)
    temp_df = pd.read_html(r.text)[0]
    return temp_df


if __name__ == "__main__":
    forbes_rank_df = forbes_rank(symbol="2021福布斯中国香港富豪榜")
    print(forbes_rank_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/1/20 23:04
Desc: 中国外汇交易中心暨全国银行间同业拆借中心-回购定盘利率-历史数据
"""

import pandas as pd
import requests


def repo_rate_query(symbol: str = "回购定盘利率") -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-回购定盘利率-历史数据
    https://www.chinamoney.com.cn/chinese/bkfrr/
    :param symbol: choice of {"回购定盘利率", "银银间回购定盘利率"}
    :type symbol: str
    :return: 回购定盘利率-历史数据
    :rtype: pandas.DataFrame
    """
    if symbol == "回购定盘利率":
        url = "https://www.chinamoney.com.cn/r/cms/www/chinamoney/data/currency/frr-chrt.csv"
        temp_df = pd.read_csv(url, header=None)
        temp_df.dropna(axis=1, inplace=True)
        temp_df.columns = ["date", "FR001", "FR007", "FR014"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["FR001"] = pd.to_numeric(temp_df["FR001"], errors="coerce")
        temp_df["FR007"] = pd.to_numeric(temp_df["FR007"], errors="coerce")
        temp_df["FR014"] = pd.to_numeric(temp_df["FR014"], errors="coerce")
        temp_df.sort_values(by=["date"], ignore_index=True, inplace=True)
        return temp_df
    else:
        url = "https://www.chinamoney.com.cn/r/cms/www/chinamoney/data/currency/fdr-chrt.csv"
        temp_df = pd.read_csv(url, header=None)
        temp_df.dropna(axis=1, inplace=True)
        temp_df.columns = ["date", "FDR001", "FDR007", "FDR014"]
        temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
        temp_df["FDR001"] = pd.to_numeric(temp_df["FDR001"], errors="coerce")
        temp_df["FDR007"] = pd.to_numeric(temp_df["FDR007"], errors="coerce")
        temp_df["FDR014"] = pd.to_numeric(temp_df["FDR014"], errors="coerce")
        temp_df.sort_values(by=["date"], ignore_index=True, inplace=True)
        return temp_df


def repo_rate_hist(
    start_date: str = "20200930", end_date: str = "20201029"
) -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-回购定盘利率-历史数据
    https://www.chinamoney.com.cn/chinese/bkfrr/
    :param start_date: 开始时间, 开始时间与结束时间需要在一个月内
    :type start_date: str
    :param end_date: 结束时间, 开始时间与结束时间需要在一个月内
    :type end_date: str
    :return: 回购定盘利率-历史数据
    :rtype: pandas.DataFrame
    """
    start_date = "-".join([start_date[:4], start_date[4:6], start_date[6:]])
    end_date = "-".join([end_date[:4], end_date[4:6], end_date[6:]])
    url = "https://www.chinamoney.com.cn/ags/ms/cm-u-bk-currency/FrrHis"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36",
    }
    params = {
        "lang": "CN",
        "startDate": start_date,
        "endDate": end_date,
    }
    r = requests.post(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["records"])
    temp_df = pd.DataFrame([item for item in temp_df["frValueMap"].to_list()])
    temp_df = temp_df[
        [
            "date",
            "FR001",
            "FR007",
            "FR014",
            "FDR001",
            "FDR007",
            "FDR014",
        ]
    ]
    temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
    temp_df["FR001"] = pd.to_numeric(temp_df["FR001"], errors="coerce")
    temp_df["FR007"] = pd.to_numeric(temp_df["FR007"], errors="coerce")
    temp_df["FR014"] = pd.to_numeric(temp_df["FR014"], errors="coerce")
    temp_df["FDR001"] = pd.to_numeric(temp_df["FDR001"], errors="coerce")
    temp_df["FDR007"] = pd.to_numeric(temp_df["FDR007"], errors="coerce")
    temp_df["FDR014"] = pd.to_numeric(temp_df["FDR014"], errors="coerce")
    temp_df.sort_values(["date"], ignore_index=True, inplace=True)
    return temp_df


if __name__ == "__main__":
    repo_rate_query_df = repo_rate_query(symbol="回购定盘利率")
    print(repo_rate_query_df)

    repo_rate_hist_df = repo_rate_hist(start_date="20231001", end_date="20240101")
    print(repo_rate_hist_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/1/7 17:02
Desc: 东方财富网-数据中心-新股申购-首发申报信息-首发申报企业信息
https://data.eastmoney.com/xg/xg/sbqy.html
"""

import pandas as pd
import requests

from akshare.utils import demjson


def stock_ipo_declare() -> pd.DataFrame:
    """
    东方财富网-数据中心-新股申购-首发申报信息-首发申报企业信息
    https://data.eastmoney.com/xg/xg/sbqy.html
    :return: 首发申报企业信息
    :rtype: pandas.DataFrame
    """
    url = "https://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "st": "1",
        "sr": "-1",
        "ps": "500",
        "p": "1",
        "type": "NS",
        "sty": "NSFR",
        "js": "({data:[(x)],pages:(pc)})",
        "mkt": "1",
        "fd": "2021-04-02",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = temp_df.index + 1
    temp_df.columns = [
        "序号",
        "会计师事务所",
        "_",
        "保荐机构",
        "_",
        "律师事务所",
        "_",
        "_",
        "拟上市地",
        "_",
        "_",
        "备注",
        "申报企业",
        "_",
        "_",
        "_",
        "_",
    ]
    temp_df = temp_df[
        [
            "序号",
            "申报企业",
            "拟上市地",
            "保荐机构",
            "会计师事务所",
            "律师事务所",
            "备注",
        ]
    ]
    return temp_df


if __name__ == "__main__":
    stock_ipo_declare_df = stock_ipo_declare()
    print(stock_ipo_declare_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/10/30 21:12
Desc: 新财富 500 人富豪榜
http://www.xcf.cn/zhuanti/ztzz/hdzt1/500frb/index.html
"""

import json

import pandas as pd
import requests


def xincaifu_rank(year: str = "2022") -> pd.DataFrame:
    """
    新财富 500 人富豪榜
    http://www.xcf.cn/zhuanti/ztzz/hdzt1/500frb/index.html
    :param year: 具体排名年份, 数据从 2003-至今
    :type year: str
    :return: 排行榜
    :rtype: pandas.DataFrame
    """
    url = "http://service.ikuyu.cn/XinCaiFu2/pcremoting/bdListAction.do"
    params = {
        "method": "getPage",
        "callback": "jsonpCallback",
        "sortBy": "",
        "order": "",
        "type": "4",
        "keyword": "",
        "pageSize": "1000",
        "year": year,
        "pageNo": "1",
        "from": "jsonp",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = json.loads(data_text[data_text.find("{") : -1])
    temp_df = pd.DataFrame(data_json["data"]["rows"])
    temp_df.columns
    temp_df.rename(
        columns={
            "assets": "财富",
            "year": "年份",
            "sex": "性别",
            "name": "姓名",
            "rank": "排名",
            "company": "主要公司",
            "industry": "相关行业",
            "id": "-",
            "addr": "公司总部",
            "rankLst": "-",
            "age": "年龄",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "排名",
            "财富",
            "姓名",
            "主要公司",
            "相关行业",
            "公司总部",
            "性别",
            "年龄",
            "年份",
        ]
    ]
    return temp_df


if __name__ == "__main__":
    xincaifu_rank_df = xincaifu_rank(year="2022")
    print(xincaifu_rank_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/29 16:00
Desc: 中国证券投资基金业协会-信息公示数据
中国证券投资基金业协会-新版: https://gs.amac.org.cn
"""

import pandas as pd
import requests

from akshare.utils.tqdm import get_tqdm

headers = {
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
    "Chrome/123.0.0.0 Safari/537.36",
    "Content-Type": "application/json",
}


def _get_pages(url: str = "", payload: str = "") -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-私募基金管理人公示 页数
    暂时不使用本函数, 直接可以获取所有数据
    """
    res = requests.post(url=url, json=payload, headers=headers)
    res.encoding = "utf-8"
    json_df = res.json()
    return json_df["totalPages"]


def get_data(url: str = "", payload: str = "") -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-私募基金管理人公示
    """
    res = requests.post(url=url, json=payload, headers=headers)
    res.encoding = "utf-8"
    json_df = res.json()
    return json_df


# 中国证券投资基金业协会-信息公示-会员信息
# 中国证券投资基金业协会-信息公示-会员信息-会员机构综合查询
def amac_member_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-会员信息-会员机构综合查询
    https://gs.amac.org.cn/amac-infodisc/res/pof/member/index.html
    :return: 会员机构综合查询
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/pofMember"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "20",
    }
    r = requests.post(url, params=params, json={}, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "managerName",
        "memberBehalf",
        "memberType",
        "memberCode",
        "memberDate",
        "primaryInvestType",
        "markStar",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "机构（会员）名称",
        "会员代表",
        "会员类型",
        "会员编号",
        "入会时间",
        "机构类型",
        "是否星标",
    ]
    manager_data_out["入会时间"] = pd.to_datetime(
        manager_data_out["入会时间"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-从业人员信息
# 中国证券投资基金业协会-信息公示-从业人员信息-基金从业人员资格注册信息
def amac_person_fund_org_list(symbol: str = "公募基金管理公司") -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-从业人员信息-基金从业人员资格注册信息
    https://gs.amac.org.cn/amac-infodisc/res/pof/person/personOrgList.html
    :param symbol: choice of {"公募基金管理公司", "公募基金管理公司资管子公司", "商业银行", "证券公司", "证券公司子公司",
    "私募基金管理人", "保险公司子公司", "保险公司", "外包服务机构", "期货公司", "期货公司资管子公司", "媒体机构",
    "证券投资咨询机构", "评价机构", "外资私募证券基金管理人", "支付结算", "独立服务机构", "地方自律组织", "境外机构",
    "律师事务所", "会计师事务所", "交易所", "独立第三方销售机构", "证券公司资管子公司", "证券公司私募基金子公司", "其他"}
    :type symbol: str
    :return: 基金从业人员资格注册信息
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "保险公司子公司": "bxgszgs",
        "期货公司资管子公司": "qhgszgzgs",
        "公募基金管理公司资管子公司": "gmjjglgszgzgs",
        "商业银行": "syyh",
        "交易所": "jys",
        "证券公司私募基金子公司": "zqgssmjjzgs",
        "地方自律组织": "dfzlzz",
        "证券公司": "zqgs",
        "评价机构": "pjjg",
        "独立第三方销售机构": "dldsfxsjg",
        "证券投资咨询机构": "zqtzzxjg",
        "外资私募证券基金管理人": "wzsmzqjjglr",
        "境外机构": "jwjg",
        "证券公司子公司": "zqgszgs",
        "公募基金管理公司": "gmjjglgs",
        "媒体机构": "mtjg",
        "支付结算": "zfjs",
        "证券公司资管子公司": "zqgszgzgs",
        "会计师事务所": "kjssws",
        "独立服务机构": "dlfwjg",
        "律师事务所": "lssws",
        "期货公司": "qhgs",
        "保险公司": "bxgs",
        "其他": "qt",
        "外包服务机构": "wbfwjg",
        "私募基金管理人": "smjjglr",
    }
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/personOrg"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "20",
    }
    r = requests.post(
        url,
        params=params,
        json={"orgType": symbol_map[symbol], "page": "1"},
        headers=headers,
    )
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(
            url,
            params=params,
            json={"orgType": symbol_map[symbol], "page": "1"},
            verify=False,
            headers=headers,
        )
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "orgName",
        "orgType",
        "workerTotalNum",
        "operNum",
        "salesmanNum",
        "investmentManagerNum",
        "fundManagerNum",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.reset_index(inplace=True)
    manager_data_out["index"] = manager_data_out.index + 1
    manager_data_out.columns = [
        "序号",
        "机构名称",
        "机构类型",
        "员工人数",
        "基金从业资格",
        "基金销售业务资格",
        "基金经理",
        "投资经理",
    ]
    manager_data_out["员工人数"] = pd.to_numeric(manager_data_out["员工人数"])
    manager_data_out["基金从业资格"] = pd.to_numeric(manager_data_out["基金从业资格"])
    manager_data_out["基金销售业务资格"] = pd.to_numeric(
        manager_data_out["基金销售业务资格"]
    )
    manager_data_out["基金经理"] = pd.to_numeric(manager_data_out["基金经理"])
    manager_data_out["投资经理"] = pd.to_numeric(manager_data_out["投资经理"])
    return manager_data_out


# 中国证券投资基金业协会-信息公示-从业人员信息-债券投资交易相关人员公示
def amac_person_bond_org_list() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-从业人员信息-债券投资交易相关人员公示
    https://human.amac.org.cn/web/org/personPublicity.html
    :return: 债券投资交易相关人员公示
    :rtype: pandas.DataFrame
    """
    import urllib3
    import ssl

    ctx = ssl.create_default_context()
    ctx.options |= ssl.OP_LEGACY_SERVER_CONNECT
    # 使用自定义的 SSL 上下文发起 HTTPS 请求
    http = urllib3.PoolManager(ssl_context=ctx)

    url = "https://human.amac.org.cn/web/api/publicityAddress?rand=0.6288001872566391&pageNum=1&pageSize=5000"
    r = http.request(method="GET", url=url)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["list"])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = range(1, len(temp_df) + 1)
    temp_df.columns = [
        "序号",
        "_",
        "_",
        "机构名称",
        "机构类型",
        "公示网址",
    ]
    temp_df = temp_df[
        [
            "序号",
            "机构类型",
            "机构名称",
            "公示网址",
        ]
    ]
    return temp_df


# 中国证券投资基金业协会-信息公示-私募基金管理人公示
# 中国证券投资基金业协会-信息公示-私募基金管理人公示-私募基金管理人综合查询
def amac_manager_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-私募基金管理人公示-私募基金管理人综合查询
    https://gs.amac.org.cn/amac-infodisc/res/pof/manager/index.html
    :return: 私募基金管理人综合查询
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/manager"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "managerName",
        "artificialPersonName",
        "primaryInvestType",
        "registerProvince",
        "registerNo",
        "establishDate",
        "registerDate",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "私募基金管理人名称",
        "法定代表人/执行事务合伙人(委派代表)姓名",
        "机构类型",
        "注册地",
        "登记编号",
        "成立时间",
        "登记时间",
    ]
    manager_data_out["成立时间"] = pd.to_datetime(
        manager_data_out["成立时间"], unit="ms"
    ).dt.date
    manager_data_out["登记时间"] = pd.to_datetime(
        manager_data_out["登记时间"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-私募基金管理人公示-私募基金管理人分类公示
def amac_manager_classify_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-私募基金管理人公示-私募基金管理人分类公示
    https://gs.amac.org.cn/amac-infodisc/res/pof/manager/managerList.html
    :return: 私募基金管理人分类公示
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/manager"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "managerName",
        "artificialPersonName",
        "primaryInvestType",
        "registerNo",
        "registerProvince",
        "officeAdrAgg",
        "establishDate",
        "registerDate",
        "fundCount",
        "memberType",
        "hasSpecialTips",
        "hasCreditTips",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "私募基金管理人名称",
        "法定代表人/执行事务合伙人(委派代表)姓名",
        "机构类型",
        "登记编号",
        "注册地",
        "办公地",
        "成立时间",
        "登记时间",
        "在管基金数量",
        "会员类型",
        "是否有提示信息",
        "是否有诚信信息",
    ]
    manager_data_out["成立时间"] = pd.to_datetime(
        manager_data_out["成立时间"], unit="ms"
    ).dt.date
    manager_data_out["登记时间"] = pd.to_datetime(
        manager_data_out["登记时间"], unit="ms"
    ).dt.date
    manager_data_out["在管基金数量"] = pd.to_numeric(manager_data_out["在管基金数量"])
    manager_data_out["是否有提示信息"] = manager_data_out["是否有提示信息"].map(
        {True: "是", False: "否"}
    )
    manager_data_out["是否有诚信信息"] = manager_data_out["是否有诚信信息"].map(
        {True: "是", False: "否"}
    )
    return manager_data_out


# 中国证券投资基金业协会-信息公示-私募基金管理人公示-证券公司私募基金子公司管理人信息公示
def amac_member_sub_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-私募基金管理人公示-证券公司私募基金子公司管理人信息公示
    https://gs.amac.org.cn/amac-infodisc/res/pof/member/index.html?primaryInvestType=private
    :return: 证券公司私募基金子公司管理人信息公示
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/pofMember"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "managerName",
        "memberBehalf",
        "memberType",
        "memberCode",
        "memberDate",
        "primaryInvestType",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "机构（会员）名称",
        "会员代表",
        "会员类型",
        "会员编号",
        "入会时间",
        "公司类型",
    ]
    manager_data_out["入会时间"] = pd.to_datetime(
        manager_data_out["入会时间"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-基金产品
# 中国证券投资基金业协会-信息公示-基金产品-私募基金管理人基金产品
def amac_fund_info(start_page: str = "1", end_page: str = "2000") -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品-私募基金管理人基金产品
    https://gs.amac.org.cn/amac-infodisc/res/pof/fund/index.html
    :param start_page: 开始页码, 获取指定页码直接的数据
    :type start_page: str
    :param end_page: 结束页码, 获取指定页码直接的数据
    :type end_page: str
    :return: 私募基金管理人基金产品
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/fund"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = int(data_json["totalPages"])
    if total_page > int(end_page):
        real_end_page = int(end_page)
    else:
        real_end_page = total_page
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(int(start_page) - 1, real_end_page), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "fundName",
        "managerName",
        "managerType",
        "workingState",
        "putOnRecordDate",
        "establishDate",
        "mandatorName",
    ]  # 定义要取的 value 的 keys
    manager_data_out = big_df[keys_list].copy()
    manager_data_out.columns = [
        "基金名称",
        "私募基金管理人名称",
        "私募基金管理人类型",
        "运行状态",
        "备案时间",
        "建立时间",
        "托管人名称",
    ]
    manager_data_out["建立时间"] = pd.to_datetime(
        manager_data_out["建立时间"], unit="ms"
    ).dt.date
    manager_data_out["备案时间"] = pd.to_datetime(
        manager_data_out["备案时间"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-基金产品-证券公司集合资管产品公示
def amac_securities_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品公示-证券公司集合资管产品公示
    https://gs.amac.org.cn/amac-infodisc/res/pof/securities/index.html
    :return: 证券公司集合资管产品公示
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/securities"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "cpmc",
        "cpbm",
        "gljg",
        "slrq",
        "dqr",
        "tzlx",
        "sffj",
        "tgjg",
        "barq",
        "yzzt",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "产品名称",
        "产品编码",
        "管理人名称",
        "成立日期",
        "到期时间",
        "投资类型",
        "是否分级",
        "托管人名称",
        "备案日期",
        "运作状态",
    ]
    return manager_data_out


# 中国证券投资基金业协会-信息公示-基金产品-证券公司直投基金
def amac_aoin_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品公示-证券公司直投基金
    https://gs.amac.org.cn/amac-infodisc/res/aoin/product/index.html
    :return: 证券公司直投基金
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/aoin/product"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "code",
        "name",
        "aoinName",
        "managerName",
        "createDate",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "产品编码",
        "产品名称",
        "直投子公司",
        "管理机构",
        "设立日期",
    ]
    manager_data_out["设立日期"] = pd.to_datetime(
        manager_data_out["设立日期"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-基金产品公示-证券公司私募投资基金
def amac_fund_sub_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品公示-证券公司私募投资基金
    https://gs.amac.org.cn/amac-infodisc/res/pof/subfund/index.html
    :return: 证券公司私募投资基金
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/subfund"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "productCode",
        "productName",
        "mgrName",
        "trustee",
        "foundDate",
        "registeredDate",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "产品编码",
        "产品名称",
        "私募基金管理人名称",
        "托管人名称",
        "成立日期",
        "备案日期",
    ]
    manager_data_out["备案日期"] = pd.to_datetime(
        manager_data_out["备案日期"], unit="ms"
    ).dt.date
    manager_data_out["成立日期"] = pd.to_datetime(
        manager_data_out["成立日期"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-基金产品公示-基金公司及子公司集合资管产品公示
def amac_fund_account_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品公示-基金公司及子公司集合资管产品公示
    https://gs.amac.org.cn/amac-infodisc/res/fund/account/index.html
    :return: 基金公司及子公司集合资管产品公示
    :rtype: pandas.DataFrame
    """
    import warnings

    warnings.filterwarnings(action="ignore", category=FutureWarning)

    url = "https://gs.amac.org.cn/amac-infodisc/api/fund/account"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "registerDate",
        "registerCode",
        "name",
        "manager",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "成立日期",
        "产品编码",
        "产品名称",
        "管理人名称",
    ]
    manager_data_out["成立日期"] = pd.to_datetime(
        manager_data_out["成立日期"], unit="ms"
    ).dt.date
    return manager_data_out


# 中国证券投资基金业协会-信息公示-基金产品公示-资产支持专项计划
def amac_fund_abs() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品公示-资产支持专项计划公示信息
    https://gs.amac.org.cn/amac-infodisc/res/fund/abs/index.html
    :return: 资产支持专项计划公示信息
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/fund/abs"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df["index"] = range(1, len(big_df) + 1)
    big_df.columns = [
        "编号",
        "_",
        "_",
        "专项计划全称",
        "备案编号",
        "管理人",
        "托管人",
        "备案通过时间",
        "成立日期",
        "预期到期时间",
    ]
    big_df["备案通过时间"] = pd.to_datetime(big_df["备案通过时间"], unit="ms").dt.date
    big_df["成立日期"] = pd.to_datetime(big_df["成立日期"], unit="ms").dt.date
    big_df["预期到期时间"] = pd.to_datetime(
        big_df["预期到期时间"], unit="ms", errors="coerce"
    ).dt.date
    big_df = big_df[
        [
            "编号",
            "备案编号",
            "专项计划全称",
            "管理人",
            "托管人",
            "成立日期",
            "预期到期时间",
            "备案通过时间",
        ]
    ]
    return big_df


# 中国证券投资基金业协会-信息公示-基金产品公示-期货公司集合资管产品公示
def amac_futures_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-基金产品公示-期货公司集合资管产品公示
    https://gs.amac.org.cn/amac-infodisc/res/pof/futures/index.html
    :return: 期货公司集合资管产品公示
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/pof/futures"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "mpiName",
        "mpiProductCode",
        "aoiName",
        "mpiTrustee",
        "mpiCreateDate",
        "tzlx",
        "sfjgh",
        "registeredDate",
        "dueDate",
        "fundStatus",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "产品名称",
        "产品编码",
        "管理人名称",
        "托管人名称",
        "成立日期",
        "投资类型",
        "是否分级",
        "备案日期",
        "到期日",
        "运作状态",
    ]
    return manager_data_out


# 中国证券投资基金业协会-信息公示-诚信信息
# 中国证券投资基金业协会-信息公示-诚信信息-已注销私募基金管理人名单
def amac_manager_cancelled_info() -> pd.DataFrame:
    """
    中国证券投资基金业协会-信息公示-诚信信息公示-已注销私募基金管理人名单
    https://gs.amac.org.cn/amac-infodisc/res/cancelled/manager/index.html
    主动注销: 100
    依公告注销: 200
    协会注销: 300
    :return: 已注销私募基金管理人名单
    :rtype: pandas.DataFrame
    """
    url = "https://gs.amac.org.cn/amac-infodisc/api/cancelled/manager"
    params = {
        "rand": "0.7665138514630696",
        "page": "1",
        "size": "100",
    }
    r = requests.post(url, params=params, json={}, verify=False, headers=headers)
    data_json = r.json()
    total_page = data_json["totalPages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(0, int(total_page)), leave=False):
        params.update({"page": page})
        r = requests.post(url, params=params, json={}, verify=False, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["content"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    keys_list = [
        "orgName",
        "orgCode",
        "orgSignDate",
        "cancelDate",
        "status",
    ]  # 定义要取的 value 的 keys
    manager_data_out = pd.DataFrame(big_df)
    manager_data_out = manager_data_out[keys_list]
    manager_data_out.columns = [
        "管理人名称",
        "统一社会信用代码",
        "登记时间",
        "注销时间",
        "注销类型",
    ]
    manager_data_out["登记时间"] = pd.to_datetime(
        manager_data_out["登记时间"], unit="ms"
    ).dt.date
    manager_data_out["注销时间"] = pd.to_datetime(
        manager_data_out["注销时间"], unit="ms"
    ).dt.date
    manager_data_out.sort_values(["注销时间"], ignore_index=True, inplace=True)
    return manager_data_out


if __name__ == "__main__":
    # 中国证券投资基金业协会-信息公示-会员信息
    # 中国证券投资基金业协会-信息公示-会员信息-会员机构综合查询
    amac_member_info_df = amac_member_info()
    print(amac_member_info_df)

    # 中国证券投资基金业协会-信息公示-从业人员信息
    # 中国证券投资基金业协会-信息公示-从业人员信息-基金从业人员资格注册信息
    amac_person_fund_org_list_df = amac_person_fund_org_list(symbol="公募基金管理公司")
    print(amac_person_fund_org_list_df)

    # 中国证券投资基金业协会-信息公示-从业人员信息
    # 中国证券投资基金业协会-信息公示-从业人员信息-债券投资交易相关人员公示
    amac_person_bond_org_list_df = amac_person_bond_org_list()
    print(amac_person_bond_org_list_df)

    # 中国证券投资基金业协会-信息公示-私募基金管理人公示
    # 中国证券投资基金业协会-信息公示-私募基金管理人公示-私募基金管理人综合查询
    amac_manager_info_df = amac_manager_info()
    print(amac_manager_info_df)

    # 中国证券投资基金业协会-信息公示-私募基金管理人公示-私募基金管理人分类公示
    amac_manager_classify_info_df = amac_manager_classify_info()
    print(amac_manager_classify_info_df)

    # 中国证券投资基金业协会-信息公示-私募基金管理人公示-证券公司私募基金子公司管理人信息公示
    amac_member_sub_info_df = amac_member_sub_info()
    print(amac_member_sub_info_df)

    # 中国证券投资基金业协会-信息公示-基金产品
    # 中国证券投资基金业协会-信息公示-基金产品-私募基金管理人基金产品
    amac_fund_info_df = amac_fund_info(start_page="1", end_page="100")
    print(amac_fund_info_df)

    example_df = amac_fund_info_df[
        amac_fund_info_df["私募基金管理人名称"].str.contains("聚宽")
    ]
    print(example_df)

    # 中国证券投资基金业协会-信息公示-基金产品-证券公司集合资管产品公示
    amac_securities_info_df = amac_securities_info()
    print(amac_securities_info_df)

    # 中国证券投资基金业协会-信息公示-基金产品-证券公司直投基金
    amac_aoin_info_df = amac_aoin_info()
    print(amac_aoin_info_df)

    # 中国证券投资基金业协会-信息公示-基金产品公示-证券公司私募投资基金
    amac_fund_sub_info_df = amac_fund_sub_info()
    print(amac_fund_sub_info_df)

    # 中国证券投资基金业协会-信息公示-基金产品公示-基金公司及子公司集合资管产品公示
    amac_fund_account_info_df = amac_fund_account_info()
    print(amac_fund_account_info_df)

    # 中国证券投资基金业协会-信息公示-基金产品公示-资产支持专项计划
    amac_fund_abs_df = amac_fund_abs()
    print(amac_fund_abs_df)

    # 中国证券投资基金业协会-信息公示-基金产品公示-期货公司集合资管产品公示
    amac_futures_info_df = amac_futures_info()
    print(amac_futures_info_df)

    # 中国证券投资基金业协会-信息公示-诚信信息
    # 中国证券投资基金业协会-信息公示-诚信信息-已注销私募基金管理人名单
    amac_manager_cancelled_info_df = amac_manager_cancelled_info()
    print(amac_manager_cancelled_info_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/16 12:00
Desc: 东方财富网-行情首页-沪深京 A 股
https://quote.eastmoney.com/
异步接口-测试版
"""

import asyncio
from typing import Dict, List

import aiohttp
import pandas as pd


async def fetch_single_page(
    session: aiohttp.ClientSession, url: str, params: Dict
) -> Dict:
    """异步获取单页数据"""
    async with session.get(url, params=params, ssl=False) as response:
        return await response.json()


async def fetch_all_pages_async(url: str, base_params: Dict) -> List[Dict]:
    """异步获取所有页面数据"""
    # 首先获取总数以计算页数
    first_page_params = base_params.copy()
    first_page_params["pn"] = "1"

    async with aiohttp.ClientSession() as session:
        first_page_data = await fetch_single_page(session, url, first_page_params)

        # 检查是否成功获取数据
        if first_page_data.get("rc") != 0 or not first_page_data.get("data"):
            return [first_page_data]  # 返回错误信息

        total = first_page_data["data"]["total"]
        page_size = int(base_params["pz"])
        total_pages = (total + page_size - 1) // page_size

        # 限制页数，避免过大请求
        total_pages = min(total_pages, 100)

        # 创建所有页面的任务
        tasks = []
        for page in range(1, total_pages + 1):
            page_params = base_params.copy()
            page_params["pn"] = str(page)
            tasks.append(fetch_single_page(session, url, page_params))

        # 并发执行所有任务
        results = await asyncio.gather(*tasks)
        return results


def process_data(page_results: List[Dict]) -> pd.DataFrame:
    """处理获取到的数据，转换为DataFrame"""
    all_data = []

    # 保存每个页面的结果和页码
    page_number = 1
    items_per_page = 100  # 假设每页100条

    for result in page_results:
        if result.get("rc") == 0 and result.get("data") and result["data"].get("diff"):
            page_data = result["data"]["diff"]
            for item in page_data:
                item["page_number"] = page_number
                item["page_index"] = page_data.index(item)
            all_data.extend(page_data)
            page_number += 1
    if not all_data:
        return pd.DataFrame()
    df = pd.DataFrame(all_data)
    df["序号"] = df.apply(
        lambda row: (row["page_number"] - 1) * items_per_page + row["page_index"] + 1,
        axis=1,
    )
    df.drop(columns=["page_number", "page_index"], inplace=True, errors="ignore")
    column_map = {
        "f1": "原序号",
        "f2": "最新价",
        "f3": "涨跌幅",
        "f4": "涨跌额",
        "f5": "成交量",
        "f6": "成交额",
        "f7": "振幅",
        "f8": "换手率",
        "f9": "市盈率-动态",
        "f10": "量比",
        "f11": "5分钟涨跌",
        "f12": "代码",
        "f13": "_",
        "f14": "名称",
        "f15": "最高",
        "f16": "最低",
        "f17": "今开",
        "f18": "昨收",
        "f20": "总市值",
        "f21": "流通市值",
        "f22": "涨速",
        "f23": "市净率",
        "f24": "60日涨跌幅",
        "f25": "年初至今涨跌幅",
        "f62": "-",
        "f115": "-",
        "f128": "-",
        "f136": "-",
        "f152": "-",
    }

    df.rename(columns=column_map, inplace=True)
    desired_columns = [
        "序号",
        "代码",
        "名称",
        "最新价",
        "涨跌幅",
        "涨跌额",
        "成交量",
        "成交额",
        "振幅",
        "最高",
        "最低",
        "今开",
        "昨收",
        "量比",
        "换手率",
        "市盈率-动态",
        "市净率",
        "总市值",
        "流通市值",
        "涨速",
        "5分钟涨跌",
        "60日涨跌幅",
        "年初至今涨跌幅",
    ]
    available_columns = [col for col in desired_columns if col in df.columns]
    df = df[available_columns]
    numeric_columns = [
        "最新价",
        "涨跌幅",
        "涨跌额",
        "成交量",
        "成交额",
        "振幅",
        "最高",
        "最低",
        "今开",
        "昨收",
        "量比",
        "换手率",
        "市盈率-动态",
        "市净率",
        "总市值",
        "流通市值",
        "涨速",
        "5分钟涨跌",
        "60日涨跌幅",
        "年初至今涨跌幅",
    ]
    for col in numeric_columns:
        if col in df.columns:
            df[col] = pd.to_numeric(df[col], errors="coerce")
    df.sort_values(by="涨跌幅", ascending=False, inplace=True)
    df.reset_index(drop=True, inplace=True)
    df["序号"] = df.index + 1
    return df


async def stock_zh_a_spot_em_async() -> pd.DataFrame:
    """
    异步获取东方财富网-沪深京 A 股-实时行情
    https://quote.eastmoney.com/center/gridlist.html#hs_a_board
    :return: 实时行情
    :rtype: pandas.DataFrame
    """
    url = "https://82.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": "1",
        "pz": "100",
        "po": "1",
        "np": "1",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "fid": "f12",
        "fs": "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048",
        "fields": "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,"
        "f20,f21,f23,f24,f25,f22,f11,f62,f128,f136,f115,f152",
    }
    results = await fetch_all_pages_async(url, params)
    return process_data(results)


def stock_zh_a_spot_em() -> pd.DataFrame:
    """
    东方财富网-沪深京 A 股-实时行情 (同步接口)
    https://quote.eastmoney.com/center/gridlist.html#hs_a_board
    :return: 实时行情
    :rtype: pandas.DataFrame
    """
    import nest_asyncio

    nest_asyncio.apply()
    return asyncio.run(stock_zh_a_spot_em_async())


if __name__ == "__main__":
    stock_zh_a_spot_em_df = stock_zh_a_spot_em()
    print(stock_zh_a_spot_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/6/15 15:15
Desc: 东方财富个股人气榜
https://guba.eastmoney.com/rank/
"""

import pandas as pd
import requests


def stock_hot_up_em() -> pd.DataFrame:
    """
    东方财富-个股人气榜-飙升榜
    https://guba.eastmoney.com/rank/
    :return: 飙升榜
    :rtype: pandas.DataFrame
    """
    url = "https://emappdata.eastmoney.com/stockrank/getAllHisRcList"
    payload = {
        "appId": "appId01",
        "globalId": "786e4c21-70dc-435a-93bb-38",
        "marketType": "",
        "pageNo": 1,
        "pageSize": 100,
    }
    r = requests.post(url, json=payload)
    data_json = r.json()
    temp_rank_df = pd.DataFrame(data_json["data"])

    temp_rank_df["mark"] = [
        "0" + "." + item[2:] if "SZ" in item else "1" + "." + item[2:]
        for item in temp_rank_df["sc"]
    ]
    ",".join(temp_rank_df["mark"]) + "?v=08926209912590994"
    params = {
        "ut": "f057cbcbce2a86e2866ab8877db1d059",
        "fltt": "2",
        "invt": "2",
        "fields": "f14,f3,f12,f2",
        "secids": ",".join(temp_rank_df["mark"]) + ",?v=08926209912590994",
    }
    url = "https://push2.eastmoney.com/api/qt/ulist.np/get"
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["diff"])
    temp_df.columns = ["最新价", "涨跌幅", "代码", "股票名称"]
    temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce")
    temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce")
    temp_df["涨跌额"] = temp_df["最新价"] * temp_df["涨跌幅"] / 100
    temp_df["当前排名"] = temp_rank_df["rk"]
    temp_df["代码"] = temp_rank_df["sc"]
    temp_df["排名较昨日变动"] = temp_rank_df["hrc"]
    temp_df = temp_df[
        [
            "排名较昨日变动",
            "当前排名",
            "代码",
            "股票名称",
            "最新价",
            "涨跌额",
            "涨跌幅",
        ]
    ]
    temp_df["排名较昨日变动"] = pd.to_numeric(
        temp_df["排名较昨日变动"], errors="coerce"
    )
    temp_df["当前排名"] = pd.to_numeric(temp_df["当前排名"], errors="coerce")
    temp_df["最新价"] = pd.to_numeric(temp_df["最新价"], errors="coerce")
    temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce")
    return temp_df


if __name__ == "__main__":
    stock_hot_up_em_df = stock_hot_up_em()
    print(stock_hot_up_em_df)
